profcheck

package module
v0.0.0-...-5aaae23 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 22, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package profcheck allows to verify that a ProfilesData proto conforms with the signal schema requirements and spec.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ConformanceChecker

type ConformanceChecker struct {
	CheckDictionaryDuplicates bool
	CheckSampleTimestampShape bool
}

ConformanceChecker encapsulates OpenTelemetry Profiles signal checks for conformance of the given proto to the signal requirements and conventions.

func (ConformanceChecker) Check

type SampleShape

type SampleShape int

SampleShape represents the values vs timestamps combination of sample data.

const (
	SampleShapeUnspecified    SampleShape = iota
	SampleShapeValuesOnly                 // Values only, no timestamps
	SampleShapeTimestampsOnly             // Timestamps only, no explicit values.
	SampleShapeBoth                       // Both timestamps and values, as parallel arrays.
)

func (SampleShape) String

func (s SampleShape) String() string

Directories

Path Synopsis
cmd
profcheck command
profcheck is a tool that verifies that a ProfilesData proto conforms with the signal schema requirements and spec.
profcheck is a tool that verifies that a ProfilesData proto conforms with the signal schema requirements and spec.

Jump to