Documentation
¶
Overview ¶
Package profcheck allows to verify that a ProfilesData proto conforms with the signal schema requirements and spec.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConformanceChecker ¶
ConformanceChecker encapsulates OpenTelemetry Profiles signal checks for conformance of the given proto to the signal requirements and conventions.
func (ConformanceChecker) Check ¶
func (c ConformanceChecker) Check(data *profiles.ProfilesData) error
type SampleShape ¶
type SampleShape int
SampleShape represents the values vs timestamps combination of sample data.
const ( SampleShapeUnspecified SampleShape = iota SampleShapeValuesOnly // Values only, no timestamps SampleShapeTimestampsOnly // Timestamps only, no explicit values. SampleShapeBoth // Both timestamps and values, as parallel arrays. )
func (SampleShape) String ¶
func (s SampleShape) String() string
Click to show internal directories.
Click to hide internal directories.